===================
History and credits
===================

Changelog
=========

The project follows the `Semantic Versioning`_ specification for its
version numbers.  Patch-level increments indicate bug fixes, minor
version increments indicate new functionality and major version
increments indicate backwards incompatible changes.

Version 1.0.0 is the last to support Django < 1.7.  Users of older Django
versions should stick to 1.0.0, and are encouraged to upgrade their setups.
Starting with 2.0.0, dropping support for obsolete Django versions is not
considered to be a backward-incompatible change.

.. _`Semantic Versioning`: http://semver.org/

.. include:: ../CHANGELOG.rst


Credits
=======

.. include:: ../AUTHORS.rst


.. _helping-out:

Helping out
===========

.. include:: ../README.rst
    :start-after: .. start contribute include
    :end-before: .. end contribute include

